@@ -169,7 +169,7 @@ class ApplianceImageCreator(ImageCreator):
                                            self._instroot)
 
         for p in parts:
-            self.__instloop.add_partition(int(p.size), p.disk, p.mountpoint, p.fstype)
+            self.__instloop.add_partition(int(p.size), p.disk, p.mountpoint, p.fstype, p.active)
 
         try:
             self.__instloop.mount()
@@ -300,7 +300,7 @@ class ApplianceImageCreator(ImageCreator):
         fullpathsyslinux = find_binary_path("extlinux")
         rc = subprocess.call([fullpathsyslinux, "-i", "%s/boot/extlinux" % self._instroot])
         if rc != 0:
-            raise MountError("Unable to install syslinux bootloader to %sp)d" % (loopdev, (bootdevnum + 1)))
+            raise MountError("Unable to install syslinux bootloader to %sp%d" % (loopdev, (bootdevnum + 1)))
 
     def _create_bootconfig(self):
         self._create_syslinux_config()
