@@ -115,9 +115,19 @@ class PartitionedMount(Mount):
                                      "%dM" % p['start'], "%dM" % (p['start'] + d['extended'])],
                                      stdout = dev_null, stderr = dev_null)
 
+            if p['fstype'] == "swap":
+                parted_fs_type = "linux-swap"
+            elif p['fstype'] == "vfat":
+                parted_fs_type = "fat32"
+            elif p['fstype'] == "msdos":
+                parted_fs_type = "fat16"
+            else:
+                # Type for ext2/ext3/ext4/btrfs
+                parted_fs_type = "ext2"
+
             logging.debug("Add %s part at %d of size %d" % (p['type'], p['start'], p['size']))
             rc = subprocess.call([self.parted, "-s", d['disk'].device, "mkpart",
-                                 p['type'], "%dM" % p['start'], "%dM" % (p['start']+p['size'])],
+                                 p['type'], parted_fs_type, "%dM" % p['start'], "%dM" % (p['start']+p['size'])],
                                  stdout = dev_null, stderr = dev_null)
 
             if p['boot']:
@@ -180,19 +190,28 @@ class PartitionedMount(Mount):
                 # to match their parent device + partition num
                 # kpartx doesn't work like this, so we add compat
                 # symlinks to point to /dev/mapper
-                if os.path.exists(loopdev):
+                if os.path.lexists(loopdev):
                     os.unlink(loopdev)
                 os.symlink(mapperdev, loopdev)
 
             logging.debug("Adding partx mapping for %s" % d['disk'].device)
-            rc = subprocess.call([self.kpartx, "-v", "-a", d['disk'].device],
-                                 stdout=dev_null, stderr=dev_null)
-            if rc != 0:
+            p1 = subprocess.Popen([self.kpartx, "-v", "-a", d['disk'].device],
+                                  stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
+            
+            (out,err) = p1.communicate()
+            logging.debug(out)
+            
+            if p1.returncode != 0:
+                # Make sure that the device maps are also removed on error case.
+                # The d['mapped'] isn't set to True if the kpartx fails so
+                # failed mapping will not be cleaned on cleanup either.
+                subprocess.call([self.kpartx, "-d", d['disk'].device],
+                                stdout=dev_null, stderr=dev_null)
                 os.close(dev_null)
                 raise MountError("Failed to map partitions for '%s'" %
                                  d['disk'].device)
             d['mapped'] = True
-            os.close(dev_null)
+        os.close(dev_null)
 
 
     def __unmap_partitions(self):
