@@ -244,13 +244,79 @@ class ImageMount:
                 raise imgcreate.CreatorError("Failed to loopback mount '%s' : %s" %
                                   (self.img, e))
         elif self.imgtype == "raw":
+            partedcmd = find_binary_path("parted")
+
             self.disk = imgcreate.SparseLoopbackDisk(self.img, self.imgsize)
             self.extmnt = targetdir
             self.tmpoutdir = imgcreate.mkdtemp()
             self.imgloop = appcreate.PartitionedMount({'/dev/sdb':self.disk}, self.extmnt, skipformat = True)
             self.img_fstype = "ext3"
-            self.imgloop.add_partition(self.imgsize/1024/1024, "/dev/sdb", "/", self.img_fstype, boot=False)
             self.extloop = None
+            
+            # Check the partitions from raw disk.
+            p1 = subprocess.Popen([partedcmd,"-s",self.img,"unit","B","print"],
+                                  stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
+            out,err = p1.communicate()
+            lines = out.strip().split("\n")
+            
+            root_mounted = False
+            partition_mounts = 0
+
+            for line in lines:
+                line = line.strip()
+                # Lines that start with number are the partitions,
+                # because parted can be translated we can't refer to any text lines.
+                if not line or not line[0].isdigit():
+                    continue
+                
+                # Some vars have extra , as list seperator.
+                line = line.replace(",","")
+                
+                # Example of parted output lines that are handled:
+                # Number  Start        End          Size         Type     File system     Flags
+                #  1      512B         3400000511B  3400000000B  primary
+                #  2      3400531968B  3656384511B  255852544B   primary  linux-swap(v1)
+                #  3      3656384512B  3720347647B  63963136B    primary  fat16           boot, lba
+
+                partition_info = re.split("\s+",line)
+
+                size = partition_info[3].split("B")[0]
+
+                if len(partition_info) < 6:
+                    # No filesystem can be found from partition line. Assuming
+                    # btrfs, because that is the only MeeGo fs that parted does 
+                    # not recognize properly.
+                    # TODO: Can we make better assumption?
+                    fstype = "btrfs"
+                elif partition_info[5] in ["ext2","ext3","ext4","btrfs"]:
+                    fstype = partition_info[5]
+                elif partition_info[5] in ["fat16","fat32"]:
+                    fstype = "vfat"
+                elif "swap" in partition_info[5]:
+                    fstype = "swap"
+                else:
+                    raise imgcreate.CreatorError("Could not recognize partition fs type '%s'." % partition_info[5])
+
+                if not root_mounted and fstype in ["ext2","ext3","ext4","btrfs"]:
+                    # TODO: Check that this is actually the valid root partition from /etc/fstab
+                    mountpoint = "/"
+                    root_mounted = True
+                elif fstype == "swap":
+                    mountpoint = "swap"
+                else:
+                    # TODO: Assing better mount points for the rest of the partitions.
+                    partition_mounts += 1
+                    mountpoint = "/media/partition_%d" % partition_mounts
+
+                if "boot" in partition_info:
+                    boot = True
+                else:
+                    boot = False
+                
+                print "Size: %s Bytes, fstype: %s, mountpoint: %s, boot: %s" % ( size, fstype, mountpoint, boot )
+                # TODO: add_partition should take bytes as size parameter.
+                self.imgloop.add_partition((int)(size)/1024/1024, "/dev/sdb", mountpoint, fstype = fstype, boot = boot)
+            
             try:
                 self.imgloop.mount()
                 self.os_image = self.img
@@ -327,25 +393,40 @@ def chroot(chrootdir, bindmounts = None, execute = "/bin/bash"):
         os.chroot(chrootdir)
         os.chdir("/")
 
+    dev_null = os.open("/dev/null", os.O_WRONLY)
+    files_to_check = ["/bin/bash", "/sbin/init"]
+    
+    architecture_found = False
+
     """ Register statically-linked qemu-arm if it is an ARM fs """
     qemu_emulator = None
-    dev_null = os.open("/dev/null", os.O_WRONLY)
-    file = subprocess.Popen([filecmd, chrootdir + "/sbin/init"], stdout=subprocess.PIPE, stderr=dev_null)
-    fileOutput = file.communicate()[0].strip().split("\n")
-    os.close(dev_null)
-    if file.returncode:
-        raise imgcreate.CreatorError("Failed to get architecture of /sbin/init")
 
-    need_qemu = False
-    i = 0
-    while i < len(fileOutput):
-        if fileOutput[i].find("ARM") > 0:
-            need_qemu = True
+    for ftc in files_to_check:
+        ftc = "%s/%s" % (chrootdir,ftc)
+        
+        # Return code of 'file' is "almost always" 0 based on some man pages
+        # so we need to check the file existance first.
+        if not os.path.exists(ftc):
+            continue
+
+        initp1 = subprocess.Popen([filecmd, ftc], stdout=subprocess.PIPE, stderr=dev_null)
+        fileOutput = initp1.communicate()[0].strip().split("\n")
+        
+        for i in range(len(fileOutput)):
+            if fileOutput[i].find("ARM") > 0:
+                qemu_emulator = imgcreate.setup_qemu_emulator(chrootdir, "arm")
+                architecture_found = True
+                break
+            if fileOutput[i].find("Intel") > 0:
+                architecture_found = True
+                break
+                
+        if architecture_found:
             break
-        i = i + 1
-
-    if need_qemu:
-       qemu_emulator = imgcreate.setup_qemu_emulator(chrootdir, "arm") 
+                
+    os.close(dev_null)
+    if not architecture_found:
+        raise imgcreate.CreatorError("Failed to get architecture from any of the following files %s from chroot." % files_to_check)
 
     try:
         print "Launching shell. Exit to continue."
@@ -353,8 +434,9 @@ def chroot(chrootdir, bindmounts = None, execute = "/bin/bash"):
         globalmounts = setup_chrootenv(chrootdir, bindmounts)
         args = shlex.split(execute)
         subprocess.call(args, preexec_fn = mychroot)
-        cleanup_chrootenv(chrootdir, bindmounts, globalmounts)
-        if qemu_emulator:
-            os.unlink(chrootdir + qemu_emulator)
     except OSError, (err, msg):
         raise imgcreate.CreatorError("Failed to chroot: %s" % msg)
+    finally:
+        cleanup_chrootenv(chrootdir, bindmounts, globalmounts)
+        if qemu_emulator:
+            os.unlink(chrootdir + qemu_emulator)        
