@@ -23,12 +23,12 @@ from mic.imgcreate.live import *
 from mic.imgcreate.creator import *
 from mic.imgcreate.ubi import *
 from mic.imgcreate.jffs2 import *
-from mic.imgcreate.yuminst import *
 from mic.imgcreate.kickstart import *
 from mic.imgcreate.fs import *
 from mic.imgcreate.misc import *
 from mic.imgcreate.bootstrap import *
 from mic.imgcreate.debug import *
+from mic.imgcreate.pkgmanagers import *
 
 """A set of classes for building Fedora system images.
 
