@@ -40,7 +40,15 @@ from mic.imgcreate.errors import *
 from mic.imgcreate.fs import *
 from mic.imgcreate.misc import *
 
+class BootstrapError(Exception):
+    """An exception base class for all bootstrap errors."""
+    def __init__(self, msg):
+        Exception.__init__(self, msg)
+
 def get_repo_metadata(repo, cachedir, reponame, proxies = {}, arch = None):
+    if not repo:
+        raise BootstrapError("Repository can't be empty string.")
+    
     makedirs(cachedir + "/" + reponame)
     url = str(repo + "/repodata/repomd.xml")
     filename = str("%s/%s/repomd.xml" % (cachedir, reponame))
@@ -369,19 +377,28 @@ def build_bootstrap(repourl, cachedir, reponame, bootstrapdir, proxies = {}, arc
                  try:
                      pkgfn = g.urlgrab(url = pkgurl, filename = pkgfn, proxies = proxies)
                  except URLGrabError, e:
-                     raise CreatorError("URLGrabber error: %s: %s" % (e, pkgurl))
+                     raise BootstrapError("URLGrabber error: %s: %s" % (e, pkgurl))
                  except:
-                     raise CreatorError("URLGrabber error: %s" % pkgurl)
+                     raise BootstrapError("URLGrabber error: %s" % pkgurl)
         install_rpm(pkgfn, pkg, bootstrapdir, force)
         installed_pkgs.append(pkg)
 
     # First install a mini base
-    pkglist = ["bash", "setup", "filesystem", "basesystem", "nss-softokn-freebl", "cpio", "info", "glibc-common", "libgcc", "glibc"]
+    pkglist = [ "setup", "filesystem", "basesystem", "tzdata",
+                "libgcc", "ncurses-base", "ncurses", "nss-softokn-freebl",
+                "glibc-common", "glibc", "ncurses-libs", "bash", "zlib",
+                "info", "cpio" ]
+    
     for pkg in pkglist:
         download_and_install(pkg, True)
 
-    pkglist = ["glibc", "passwd", "pam-modules-cracklib", "meego-release", "moblin-release", "fastinit", "nss", "genisoimage", "bzip2", "gzip", "cpio", "perl", "syslinux-extlinux", "btrfs-progs", "make", "file", "psmisc", "mic2"]
-    pkglist.extend(["isomd5sum", "wget"])
+    print "* Mini base installed. Continuing with the rest of the packages. *"
+
+    pkglist = ["glibc", "passwd", "pam-modules-cracklib", "meego-release", 
+               "moblin-release", "fastinit", "nss", "genisoimage", "bzip2", 
+               "gzip", "cpio", "perl", "syslinux-extlinux", "btrfs-progs", 
+               "make", "file", "psmisc", "mic2", "isomd5sum", "wget"]
+    
     for pkg in pkglist:
         for node in get_my_all_deps_in_order(pkg, con):
             #download_and_install(node["name"], node["isleaf"])
@@ -393,18 +410,19 @@ def build_bootstrap(repourl, cachedir, reponame, bootstrapdir, proxies = {}, arc
     for rpmdbfile in glob.glob(bootstrapdir + "/var/lib/rpm/__db.*"):
         os.unlink(rpmdbfile)
 
+    print "Installed total of %d packages to bootstrap located in %s." % (len(installed_pkgs),bootstrapdir)
+
     """ Create a emtpy file /tmp/SampleMedia.tar to avoid long download time """
     fd = open(bootstrapdir + "/tmp/SampleMedia.tar", "w")
     fd.close()
 
 def isbootstrap(rootdir):
-    ret = False
-    if (os.path.exists(rootdir + "/etc/meego-release") or os.path.exists(rootdir + "/etc/moblin-release")) \
-       and os.path.exists(rootdir + "/etc/inittab") \
-       and os.path.exists(rootdir + "/etc/rc.sysinit"):
-        ret = True
+    if (os.path.exists(rootdir + "/etc/meego-release") \
+       or os.path.exists(rootdir + "/etc/moblin-release")) \
+       and os.path.exists(rootdir + "/bin/bash"):
+        return True
 
-    return ret
+    return False
 
 def has_package_in_repo(con, pkg):
     for row in con.execute("select * from packages where name = \"%s\"" % pkg):
@@ -523,7 +541,7 @@ def convert_to(imgfile, imgfmt):
                                       "--format", "VDI"])
                 
     if rc != 0:
-        raise CreatorError("Unable to convert to %s" % imgfmt)
+        raise BootstrapError("Unable to convert to %s" % imgfmt)
     else:
         if imgfmt == "vmdk":
             vmxfile = write_image_vmx(dst)
@@ -609,7 +627,7 @@ def check_mic(bootstrap):
             output = proc.communicate()[0]
             os.close(dev_null)
             if proc.returncode != 0:
-                raise CreatorError("Failed to run /usr/bin/pycentral")
+                raise BootstrapError("Failed to run /usr/bin/pycentral")
             pycentraldir = output.split()[0]
             pythonlib = pycentraldir
             bin_path = "/usr/local/bin"
