@@ -28,17 +28,14 @@ import re
 import tarfile
 import glob
 
-import yum
 import rpm
-import rpmUtils.miscutils
-import rpmUtils.arch
 
 from mic.imgcreate.errors import *
 from mic.imgcreate.fs import *
 from mic.imgcreate.misc import *
-from mic.imgcreate.yuminst import *
 from mic.imgcreate import kickstart
-from mic.imgcreate.srcdownload import SrcDownload
+from mic.imgcreate import pkgmanagers
+from mic.imgcreate.rpmmisc import *
 
 FSLABEL_MAXLEN = 32
 """The maximum string length supported for LoopImageCreator.fslabel."""
@@ -68,6 +65,11 @@ class ImageCreator(object):
                 filesystem labels
 
         """
+
+        """ Initialize package managers """
+        self.pkgmgr = pkgmanagers.pkgManager()
+        self.pkgmgr.load_pkg_managers()
+
         self.ks = ks
         """A pykickstart.KickstartParser instance."""
 
@@ -130,7 +132,7 @@ class ImageCreator(object):
                     break
 
     def set_target_arch(self, arch):
-        if not rpmUtils.arch.arches.has_key(arch):
+        if arch not in arches.keys():
             return False
         self.target_arch = arch
         if self.target_arch.startswith("arm"):
@@ -140,6 +142,17 @@ class ImageCreator(object):
 
             if not os.path.exists("/usr/bin/qemu-arm") or not is_statically_linked("/usr/bin/qemu-arm"):
                 self._dep_checks.append("qemu-arm-static")
+                
+            if os.path.exists("/proc/sys/vm/vdso_enabled"):
+                vdso_fh = open("/proc/sys/vm/vdso_enabled","r")
+                vdso_value = vdso_fh.read().strip()
+                vdso_fh.close()
+                if (int)(vdso_value) == 1:
+                    print "\n= WARNING ="
+                    print "vdso is enabled on your host, which might cause problems with arm emulations."
+                    print "You can disable vdso with following command before starting image build:"
+                    print "echo 0 | sudo tee /proc/sys/vm/vdso_enabled"
+                    print "= WARNING =\n"
 
         return True
 
@@ -314,7 +327,7 @@ class ImageCreator(object):
         excluded_packages = []
         for rpm_path in self._get_local_packages():
             rpm_name = os.path.basename(rpm_path)
-            package_name = rpmUtils.miscutils.splitFilename(rpm_name)[0]
+            package_name = splitFilename(rpm_name)[0]
             excluded_packages += [package_name]
         return excluded_packages
 
@@ -700,12 +713,11 @@ class ImageCreator(object):
 
         return None
 
-    def __select_packages(self, ayum):
+    def __select_packages(self, pkg_manager):
         skipped_pkgs = []
         for pkg in self._required_pkgs:
-            try:
-                ayum.selectPackage(pkg)
-            except yum.Errors.InstallError, e:
+            e = pkg_manager.selectPackage(pkg)
+            if e:
                 if kickstart.ignore_missing(self.ks):
                     skipped_pkgs.append(pkg)
                 elif self.__is_excluded_pkg(pkg):
@@ -717,12 +729,11 @@ class ImageCreator(object):
         for pkg in skipped_pkgs:
             logging.warn("Skipping missing package '%s'" % (pkg,))
 
-    def __select_groups(self, ayum):
+    def __select_groups(self, pkg_manager):
         skipped_groups = []
         for group in self._required_groups:
-            try:
-                ayum.selectGroup(group.name, group.include)
-            except (yum.Errors.InstallError, yum.Errors.GroupsError), e:
+            e = pkg_manager.selectGroup(group.name, group.include)
+            if e:
                 if kickstart.ignore_missing(self.ks):
                     skipped_groups.append(group)
                 else:
@@ -732,13 +743,13 @@ class ImageCreator(object):
         for group in skipped_groups:
             logging.warn("Skipping missing group '%s'" % (group.name,))
 
-    def __deselect_packages(self, ayum):
+    def __deselect_packages(self, pkg_manager):
         for pkg in self._excluded_pkgs:
-            ayum.deselectPackage(pkg)
+            pkg_manager.deselectPackage(pkg)
 
-    def __localinst_packages(self, ayum):
+    def __localinst_packages(self, pkg_manager):
         for rpm_path in self._get_local_packages():
-            ayum.installLocal(rpm_path)
+            pkg_manager.installLocal(rpm_path)
 
     def install(self, repo_urls = {}):
         """Install packages into the install root.
@@ -773,16 +784,16 @@ class ImageCreator(object):
         keep_record = None
         if self._include_src:
             keep_record = 'include_src'
-        if self._recording_pkgs in ('name', 'contents'):
+        if self._recording_pkgs in ('name', 'content'):
             keep_record = self._recording_pkgs
 
-        ayum = LiveCDYum(keep_record, target_arch = self.target_arch)
-        ayum.setup(yum_conf, self._instroot)
+        pkg_manager = self.get_pkg_manager(keep_record, target_arch = self.target_arch)
+        pkg_manager.setup(yum_conf, self._instroot)
 
         for repo in kickstart.get_repos(self.ks, repo_urls):
             (name, baseurl, mirrorlist, inc, exc, proxy, proxy_username, proxy_password, debuginfo, source, gpgkey, disable) = repo
 
-            yr = ayum.addRepository(name, baseurl, mirrorlist, proxy, proxy_username, proxy_password)
+            yr = pkg_manager.addRepository(name, baseurl, mirrorlist, proxy, proxy_username, proxy_password)
             if inc:
                 yr.includepkgs = inc
             if exc:
@@ -796,28 +807,26 @@ class ImageCreator(object):
 
         try:
             try:
-                self.__select_packages(ayum)
-                self.__select_groups(ayum)
-                self.__deselect_packages(ayum)
-                self.__localinst_packages(ayum)
+                self.__select_packages(pkg_manager)
+                self.__select_groups(pkg_manager)
+                self.__deselect_packages(pkg_manager)
+                self.__localinst_packages(pkg_manager)
 
                 BOOT_SAFEGUARD = 256L * 1024 * 1024 # 256M
                 checksize = self._root_fs_avail
                 if checksize:
                     checksize -= BOOT_SAFEGUARD
                 if self.target_arch:
-                    ayum._add_prob_flags(rpm.RPMPROB_FILTER_IGNOREARCH)
-                ayum.runInstall(checksize)
-            except yum.Errors.RepoError, e:
-                raise CreatorError("Unable to download from repo : %s" % (e,))
-            except yum.Errors.YumBaseError, e:
-                raise CreatorError("Unable to install: %s" % (e,))
+                    pkg_manager._add_prob_flags(rpm.RPMPROB_FILTER_IGNOREARCH)
+                pkg_manager.runInstall(checksize)
+            except CreatorError, e:
+                raise CreatorError("%s" % (e,))
         finally:
             if keep_record:
-                self._pkgs_content = ayum.getAllContent()
+                self._pkgs_content = pkg_manager.getAllContent()
 
-            ayum.closeRpmDB()
-            ayum.close()
+            pkg_manager.closeRpmDB()
+            pkg_manager.close()
             os.unlink(yum_conf)
 
         # do some clean up to avoid lvm info leakage.  this sucks.
@@ -1063,6 +1072,15 @@ class ImageCreator(object):
 
         self.__img_compression_method = compression_method
 
+    def set_pkg_manager(self, name):
+        self.pkgmgr.set_default_pkg_manager(name)
+
+    def get_pkg_manager(self, recording_pkgs=None, target_arch = None):
+        pkgmgr_instance = self.pkgmgr.get_default_pkg_manager()
+        if not pkgmgr_instance:
+            raise CreatorError("No pakcgae manager available")
+        return pkgmgr_instance(creator = self, recording_pkgs = recording_pkgs, target_arch = target_arch)
+
 class LoopImageCreator(ImageCreator):
     """Installs a system into a loopback-mountable filesystem image.
 
