@@ -521,7 +521,7 @@ class ExtDiskMount(DiskMount):
                               self.disk.device])
         #                      str(self.disk.size / self.blocksize)])
         if rc != 0:
-            raise MountError("Error creating %s filesystem" % (self.fstype,))
+            raise MountError("Error creating %s filesystem on disk %s" % (self.fstype,self.disk.device))
 
         dev_null = os.open("/dev/null", os.O_WRONLY)
         try:
@@ -627,7 +627,7 @@ class VfatDiskMount(DiskMount):
         blah = [self.mkfscmd, "-n", self.fslabel, "-i", self.uuid, self.disk.device]
         rc = subprocess.call(blah)
         if rc != 0:
-            raise MountError("Error creating %s filesystem" % (self.fstype,))
+            raise MountError("Error creating %s filesystem on disk %s" % (self.fstype,self.disk.device))
         logging.debug("Tuning filesystem on %s" % self.disk.device)
 
     def __resize_filesystem(self, size = None):
@@ -727,11 +727,9 @@ class BtrfsDiskMount(DiskMount):
             logging.debug("Skip filesystem format.")
             return
         logging.debug("Formating %s filesystem on %s" % (self.fstype, self.disk.device))
-        rc = subprocess.call(["/sbin/mkfs." + self.fstype,
-                              "-L", self.fslabel,
-                              self.disk.device])
+        rc = subprocess.call([self.mkfscmd, "-L", self.fslabel, self.disk.device])
         if rc != 0:
-            raise MountError("Error creating %s filesystem" % (self.fstype,))
+            raise MountError("Error creating %s filesystem on disk %s" % (self.fstype,self.disk.device))
 
         dev_null = os.open("/dev/null", os.O_WRONLY)
         try:
