@@ -176,8 +176,8 @@ class TimezoneConfig(KickstartConfig):
         try:
             shutil.copyfile(self.path("/usr/share/zoneinfo/%s" %(tz,)),
                             self.path("/etc/localtime"))
-        except OSError, (errno, msg):
-            log.error("Error copying timezone: %s" %(msg,))
+        except (IOError, OSError), (errno, msg):
+            raise errors.KickstartError("Error copying timezone info: %s" %(msg,))
 
 
 class AuthConfig(KickstartConfig):
@@ -214,7 +214,6 @@ class RootPasswordConfig(KickstartConfig):
     def set_unencrypted(self, password):        
         for p in ("/bin/echo", "/usr/sbin/chpasswd"):
             if not os.path.exists("%s/%s" %(self.instroot, p)):
-                print "blah %" %p
                 raise errors.KickstartError("Unable to set unencrypted password due to lack of %s" % p) 
         
         p1 = subprocess.Popen(["/bin/echo", "root:%s" %password],
@@ -432,6 +431,8 @@ class RPMMacroConfig(KickstartConfig):
     def apply(self, ks):
         if not ks:
             return
+        if not os.path.exists(self.path("/etc/rpm")):
+            os.mkdir(self.path("/etc/rpm"))
         f = open(self.path("/etc/rpm/macros.imgcreate"), "w+")
         if exclude_docs(ks):
             f.write("%_excludedocs 1\n")
