@@ -29,6 +29,7 @@ from mic.imgcreate.errors import *
 from mic.imgcreate.fs import *
 from mic.imgcreate.creator import *
 from mic.appcreate.partitionedfs import *
+from mic.imgcreate.rpmmisc import *
 
 class LiveImageCreatorBase(LoopImageCreator):
     """A base class for LiveCD image creators.
@@ -701,13 +702,13 @@ hiddenmenu
         cfgf.close()
 
         # first gen mactel machines get the bootloader name wrong apparently
-        if rpmUtils.arch.getBaseArch() == "i386":
+        if getBaseArch() == "i386":
             os.link(isodir + "/EFI/boot/grub.efi", isodir + "/EFI/boot/boot.efi")
             os.link(isodir + "/EFI/boot/grub.conf", isodir + "/EFI/boot/boot.conf")
 
         # for most things, we want them named boot$efiarch
         efiarch = {"i386": "ia32", "x86_64": "x64"}
-        efiname = efiarch[rpmUtils.arch.getBaseArch()]
+        efiname = efiarch[getBaseArch()]
         os.rename(isodir + "/EFI/boot/grub.efi", isodir + "/EFI/boot/boot%s.efi" %(efiname,))
         os.link(isodir + "/EFI/boot/grub.conf", isodir + "/EFI/boot/boot%s.conf" %(efiname,))
 
@@ -896,7 +897,7 @@ class ppc64LiveImageCreator(ppcLiveImageCreator):
         return ["kernel.ppc"] + \
                ppcLiveImageCreator._get_excluded_packages(self)
 
-arch = rpmUtils.arch.getBaseArch()
+arch = getBaseArch()
 if arch in ("i386", "x86_64"):
     LiveImageCreator = x86LiveImageCreator
 elif arch in ("ppc",):
